@@ -166,7 +166,7 @@ BEGIN
     END IF;
   END LOOP;
 
-  RETURN 100 * (total_time - problem_time) / total_time;
+  RETURN (100 * (total_time - problem_time)::decimal / total_time)::decimal(7, 4);
 END;
 $$;
 
@@ -235,7 +235,7 @@ CREATE TABLE host (
   notes_url_id bytea20 DEFAULT NULL,
   notes text NOT NULL,
   icon_image_id bytea20 DEFAULT NULL,
-  icon_image_alt varchar(32) NOT NULL,
+  icon_image_alt text NOT NULL,
 
   zone_name citext NOT NULL,
   zone_id bytea20 DEFAULT NULL,
@@ -405,7 +405,7 @@ CREATE TABLE host_state (
   hard_state tinyuint NOT NULL,
   previous_soft_state tinyuint NOT NULL,
   previous_hard_state tinyuint NOT NULL,
-  check_attempt tinyuint NOT NULL,
+  check_attempt uint NOT NULL,
   severity smalluint NOT NULL,
 
   output text DEFAULT NULL,
@@ -509,7 +509,7 @@ CREATE TABLE service (
   notes_url_id bytea20 DEFAULT NULL,
   notes text NOT NULL,
   icon_image_id bytea20 DEFAULT NULL,
-  icon_image_alt varchar(32) NOT NULL,
+  icon_image_alt text NOT NULL,
 
   zone_name citext NOT NULL,
   zone_id bytea20 DEFAULT NULL,
@@ -675,7 +675,7 @@ CREATE TABLE service_state (
   hard_state tinyuint NOT NULL,
   previous_soft_state tinyuint NOT NULL,
   previous_hard_state tinyuint NOT NULL,
-  check_attempt tinyuint NOT NULL,
+  check_attempt uint NOT NULL,
   severity smalluint NOT NULL,
 
   output text DEFAULT NULL,
@@ -761,6 +761,7 @@ ALTER TABLE endpoint ALTER COLUMN zone_id SET STORAGE PLAIN;
 COMMENT ON COLUMN endpoint.id IS 'sha1(environment.id + name)';
 COMMENT ON COLUMN endpoint.environment_id IS 'environment.id';
 COMMENT ON COLUMN endpoint.name_checksum IS 'sha1(name)';
+COMMENT ON COLUMN endpoint.properties_checksum IS 'sha1(all properties)';
 COMMENT ON COLUMN endpoint.zone_id IS 'zone.id';
 
 CREATE TABLE environment (
@@ -834,7 +835,7 @@ CREATE TABLE checkcommand_argument (
   id bytea20 NOT NULL,
   environment_id bytea20 NOT NULL,
   checkcommand_id bytea20 NOT NULL,
-  argument_key varchar(64) NOT NULL,
+  argument_key varchar(255) NOT NULL,
 
   properties_checksum bytea20 NOT NULL,
 
@@ -854,7 +855,6 @@ CREATE TABLE checkcommand_argument (
 ALTER TABLE checkcommand_argument ALTER COLUMN id SET STORAGE PLAIN;
 ALTER TABLE checkcommand_argument ALTER COLUMN environment_id SET STORAGE PLAIN;
 ALTER TABLE checkcommand_argument ALTER COLUMN checkcommand_id SET STORAGE PLAIN;
-ALTER TABLE checkcommand_argument ALTER COLUMN argument_key SET STORAGE PLAIN;
 ALTER TABLE checkcommand_argument ALTER COLUMN properties_checksum SET STORAGE PLAIN;
 
 COMMENT ON COLUMN checkcommand_argument.id IS 'sha1(environment.id + checkcommand_id + argument_key)';
@@ -866,7 +866,7 @@ CREATE TABLE checkcommand_envvar (
   id bytea20 NOT NULL,
   environment_id bytea20 NOT NULL,
   checkcommand_id bytea20 NOT NULL,
-  envvar_key varchar(64) NOT NULL,
+  envvar_key varchar(255) NOT NULL,
 
   properties_checksum bytea20 NOT NULL,
 
@@ -940,7 +940,7 @@ CREATE TABLE eventcommand_argument (
   id bytea20 NOT NULL,
   environment_id bytea20 NOT NULL,
   eventcommand_id bytea20 NOT NULL,
-  argument_key varchar(64) NOT NULL,
+  argument_key varchar(255) NOT NULL,
 
   properties_checksum bytea20 NOT NULL,
 
@@ -971,7 +971,7 @@ CREATE TABLE eventcommand_envvar (
   id bytea20 NOT NULL,
   environment_id bytea20 NOT NULL,
   eventcommand_id bytea20 NOT NULL,
-  envvar_key varchar(64) NOT NULL,
+  envvar_key varchar(255) NOT NULL,
 
   properties_checksum bytea20 NOT NULL,
 
@@ -1044,7 +1044,7 @@ CREATE TABLE notificationcommand_argument (
   id bytea20 NOT NULL,
   environment_id bytea20 NOT NULL,
   notificationcommand_id bytea20 NOT NULL,
-  argument_key varchar(64) NOT NULL,
+  argument_key varchar(255) NOT NULL,
 
   properties_checksum bytea20 NOT NULL,
 
@@ -1075,7 +1075,7 @@ CREATE TABLE notificationcommand_envvar (
   id bytea20 NOT NULL,
   environment_id bytea20 NOT NULL,
   notificationcommand_id bytea20 NOT NULL,
-  envvar_key varchar(64) NOT NULL,
+  envvar_key varchar(255) NOT NULL,
 
   properties_checksum bytea20 NOT NULL,
 
@@ -1159,6 +1159,7 @@ COMMENT ON COLUMN comment.environment_id IS 'environment.id';
 COMMENT ON COLUMN comment.host_id IS 'host.id';
 COMMENT ON COLUMN comment.service_id IS 'service.id';
 COMMENT ON COLUMN comment.name_checksum IS 'sha1(name)';
+COMMENT ON COLUMN comment.properties_checksum IS 'sha1(all properties)';
 COMMENT ON COLUMN comment.name IS '255+1+255+1+36, i.e. "host.name!service.name!UUID"';
 COMMENT ON COLUMN comment.zone_id IS 'zone.id';
 
@@ -1288,6 +1289,7 @@ CREATE INDEX idx_notification_service_id ON notification(service_id);
 COMMENT ON COLUMN notification.id IS 'sha1(environment.id + name)';
 COMMENT ON COLUMN notification.environment_id IS 'environment.id';
 COMMENT ON COLUMN notification.name_checksum IS 'sha1(name)';
+COMMENT ON COLUMN notification.properties_checksum IS 'sha1(all properties)';
 COMMENT ON COLUMN notification.name IS '255+1+255+1+255, i.e. "host.name!service.name!notification.name"';
 COMMENT ON COLUMN notification.host_id IS 'host.id';
 COMMENT ON COLUMN notification.service_id IS 'service.id';
@@ -1471,7 +1473,7 @@ CREATE TABLE timeperiod_range (
   timeperiod_id bytea20 NOT NULL,
   range_key citext NOT NULL,
 
-  range_value varchar(255) NOT NULL,
+  range_value text NOT NULL,
 
   CONSTRAINT pk_timeperiod_range PRIMARY KEY (id)
 );
@@ -1846,7 +1848,7 @@ CREATE TABLE state_history (
   hard_state tinyuint NOT NULL,
   previous_soft_state tinyuint NOT NULL,
   previous_hard_state tinyuint NOT NULL,
-  check_attempt tinyuint NOT NULL,
+  check_attempt uint NOT NULL, -- may be a tinyuint, see https://icinga.com/docs/icinga-db/latest/doc/04-Upgrading/#upgrading-to-icinga-db-v112
   output text DEFAULT NULL,
   long_output text DEFAULT NULL,
   max_check_attempts uint NOT NULL,
@@ -2074,7 +2076,7 @@ ALTER TABLE history ALTER COLUMN comment_history_id SET STORAGE PLAIN;
 ALTER TABLE history ALTER COLUMN flapping_history_id SET STORAGE PLAIN;
 ALTER TABLE history ALTER COLUMN acknowledgement_history_id SET STORAGE PLAIN;
 
-CREATE INDEX idx_history_event_time ON history(event_time);
+CREATE INDEX idx_history_event_time_event_type ON history(event_time, event_type);
 CREATE INDEX idx_history_acknowledgement ON history(acknowledgement_history_id);
 CREATE INDEX idx_history_comment ON history(comment_history_id);
 CREATE INDEX idx_history_downtime ON history(downtime_history_id);
@@ -2095,7 +2097,7 @@ COMMENT ON COLUMN history.comment_history_id IS 'comment_history.comment_id';
 COMMENT ON COLUMN history.flapping_history_id IS 'flapping_history.id';
 COMMENT ON COLUMN history.acknowledgement_history_id IS 'acknowledgement_history.id';
 
-COMMENT ON INDEX idx_history_event_time IS 'History filtered/ordered by event_time';
+COMMENT ON INDEX idx_history_event_time_event_type IS 'History filtered/ordered by event_time/event_type';
 COMMENT ON INDEX idx_history_host_service_id IS 'Host/service history detail filter';
 
 CREATE TABLE sla_history_state (
@@ -2181,4 +2183,4 @@ CREATE TABLE icingadb_schema (
 ALTER SEQUENCE icingadb_schema_id_seq OWNED BY icingadb_schema.id;
 
 INSERT INTO icingadb_schema (version, timestamp)
-  VALUES (2, extract(epoch from now()) * 1000);
+  VALUES (4, extract(epoch from now()) * 1000);
