@@ -4,8 +4,8 @@ import (
 	"context"
 	"encoding/hex"
 	"encoding/json"
-	"github.com/go-redis/redis/v8"
 	"github.com/icinga/icinga-testing/services"
+	"github.com/redis/go-redis/v9"
 	"github.com/stretchr/testify/require"
 	"testing"
 	"time"
