@@ -6,13 +6,13 @@ import (
 	"database/sql"
 	_ "embed"
 	"fmt"
-	"github.com/go-redis/redis/v8"
 	"github.com/icinga/icinga-testing/services"
 	"github.com/icinga/icinga-testing/utils"
 	"github.com/icinga/icinga-testing/utils/eventually"
 	localutils "github.com/icinga/icingadb/tests/internal/utils"
 	"github.com/icinga/icingadb/tests/internal/value"
 	"github.com/jmoiron/sqlx"
+	"github.com/redis/go-redis/v9"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"go.uber.org/zap"
